@@ -152,8 +152,24 @@ def stealth_sync(page: SyncPage, config: StealthConfig = None):
 
 
 async def stealth_async(page: AsyncPage, logger: Logger):
-    # for script in (StealthConfig()).enabled_scripts:
-    #     await page.add_init_script(script)
+    # options
+    max_touch_points: int = 5
+    vendor: str = 'Apple Inc.'
+    renderer: str = 'Apple GPU'
+    nav_vendor: str = 'Apple Computer, Inc.'
+    nav_platform: str = 'iPhone'
+    hardware_concurrency: int = -1
+    #
+    opts = json.dumps({
+        'webgl_vendor': vendor,
+        'webgl_renderer': renderer,
+        'navigator_vendor': nav_vendor,
+        'navigator_platform': nav_platform,
+        'max_touch_points': max_touch_points,
+        'hardwareConcurrency': hardware_concurrency,
+    })
+    await page.add_init_script(f'const opts = {opts}')
+    await page.add_init_script(SCRIPTS['utils'])
     await page.add_init_script(SCRIPTS['touchScreen'])
     await page.add_init_script(SCRIPTS['webgl_vendor'])
     await page.add_init_script(SCRIPTS['navigator_vendor'])
